@@ -5,7 +5,7 @@ df <- data.frame(my_langs = c("Korean", "Polish"), stringsAsFactors = FALSE)
 
 test_that("area.lang", {
   skip_on_cran()
-    expect_equal(area.lang("Adyghe"), c(Adyghe = "Eurasia"))
-    expect_equal(area.lang(c("Adyghe", "Aduge")), c(Adyghe = "Eurasia", Aduge = "Africa"))
+    expect_equal(area.lang("Kabardian"), c(Kabardian = "Eurasia"))
+    expect_equal(area.lang(c("Kabardian", "Aduge")), c(Kabardian = "Eurasia", Aduge = "Africa"))
     expect_equal(area.lang(df), c(my_langs1 = "Eurasia", my_langs2 = "Eurasia"))
 })
